==> ns_asphalt9-0.7.4-py3-none-any.whl: ns_asphalt9/core/utils/track_navi_data_update.py <==
data = {
    "DOWNTOWN RISE": {
        "LL": [],
        "L": [11, 50, 61, 76, 83, 86],
        "RR": [],
        "R": [16, 34, 64],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "YY-3": [],
        "trackcn": "市中心高架桥",
    },
    "THE CITY BY THE BAY": {
        "LL": [],
        "L": [31],
        "RR": [],
        "R": [8, 33, 69, 81, 85],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "YY-3": [],
        "trackcn": "临湾城市",
    },
    "UPTOWN": {
        "LL": [],
        "L": [41, 42, 66, 67],
        "RR": [],
        "R": [6, 7, 8, 25, 26, 44, 45, 69, 70, 80, 81, 84, 85, 86, 90, 91],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "YY-3": [],
        "trackcn": "住宅区",
    },
    "DIPPING DOWN": {
        "LL": [42],
        "L": [45, 52, 89],
        "RR": [],
        "R": [4, 19, 36, 65, 68, 73, 92],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "YY-3": [],
        "trackcn": "坠落",
    },
    "LEAPS & BOUNDS": {
        "LL": [59],
        "L": [63, 79, 90],
        "RR": [],
        "R": [],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "YY-3": [],
        "trackcn": "急速飞跃",
    },
    "TIBER STREAM": {
        "LL": [],
        "L": [1, 5, 6, 9, 11, 12, 31, 32, 42, 43, 67, 95, 96],
        "RR": [],
        "R": [3, 14, 15, 26, 27, 61, 65, 73, 74, 90],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "YY-3": [],
        "trackcn": "台伯河激流",
    },
    "THE CITY THAT NEVER SLEEPS": {
        "LL": [],
        "L": [5, 6, 7, 11, 12, 60, 61, 66, 67],
        "RR": [],
        "R": [2, 3, 31, 45, 46, 82, 83],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "YY-3": [],
        "trackcn": "不夜城",
    },
    "THE PEARL OF THE ORIENT": {
        "LL": [],
        "L": [5, 6, 13, 26, 30, 63, 64, 76, 77, 87],
        "RR": [],
        "R": [40, 41, 44, 45, 57, 59, 60],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "YY-3": [],
        "trackcn": "东方明珠",
    },
    "CAVE HEAT": {
        "LL": [],
        "L": [18, 19, 37, 53, 54],
        "RR": [],
        "R": [9, 10, 28, 29, 34, 35],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "YY-3": [],
        "trackcn": "洞穴热浪",
    },
    "MOUNTAIN POLES": {
        "LL": [],
        "L": [15, 16, 41, 42, 60, 82, 88],
        "RR": [],
        "R": [26, 31, 44, 45, 75, 76],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "YY-3": [],
        "trackcn": "山巅",
    },
    "DOWNHILL RUN": {
        "LL": [],
        "L": [19, 23, 62, 74, 78, 83],
        "RR": [],
        "R": [6, 14, 30, 50, 87],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "YY-3": [],
        "trackcn": "山地速降",
    },
    "THOUSAND": {
        "LL": [],
        "L": [10, 14, 20, 25, 56, 60, 84, 85, 86],
        "RR": [],
        "R": [0, 45, 79, 82],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "YY-3": [],
        "trackcn": "尖塔耸立",
    },
    "AUCKLAND TRACK": {
        "LL": [],
        "L": [0, 5, 8, 15, 23, 35, 71, 74],
        "RR": [],
        "R": [47, 61, 67],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "YY-3": [],
        "trackcn": "奥克兰赛道",
    },
    "ANCIENT ROME": {
        "LL": [],
        "L": [13, 19, 35, 50, 65],
        "RR": [],
        "R": [39, 40, 68, 79, 89],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "YY-3": [],
        "trackcn": "古罗马",
    },
    "BEACH LANDING": {
        "LL": [],
        "L": [1, 3, 11, 40, 54],
        "RR": [],
        "R": [8, 47, 59, 81, 89],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "YY-3": [],
        "trackcn": "海滩登陆",
    },
    "QUANTUM JUMPS": {
        "LL": [],
        "L": [15, 22, 52, 85],
        "RR": [],
        "R": [18, 26, 38, 62, 65, 79],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "YY-3": [],
        "trackcn": "量子跃迁",
    },
    "ROLLER": {
        "LL": [],
        "L": [3, 53, 66, 82],
        "RR": [23],
        "R": [19, 46, 56],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "YY-3": [],
        "trackcn": "云霄飞车",
    },
    "URBAN BLAZE": {
        "LL": [],
        "L": [51, 55, 68, 88],
        "RR": [],
        "R": [2, 9, 28, 33, 83],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "YY-3": [],
        "trackcn": "城市烈焰",
    },
    "WHIRLWIND": {
        "LL": [],
        "L": [4, 8, 79],
        "RR": [],
        "R": [18, 41, 68, 85, 92],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "YY-3": [],
        "trackcn": "旋风弯道",
    },
    "SHEN CITY": {
        "LL": [],
        "L": [5, 26, 50, 85],
        "RR": [],
        "R": [16, 22, 44, 67, 90],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "YY-3": [],
        "trackcn": "申城",
    },
    "THE PATH OF THE WIND": {
        "LL": [],
        "L": [22],
        "RR": [49],
        "R": [25],
        "B": [],
        "BB": [8],
        "YY-1": [18],
        "YY-2": [54],
        "YY-3": [69],
        "trackcn": "风之小径",
    },
    "TRANSCONTINE RACE": {
        "LL": [],
        "L": [],
        "RR": [13],
        "R": [2],
        "B": [],
        "BB": [51],
        "YY-1": [65],
        "YY-2": [94],
        "YY-3": [],
        "trackcn": "横贯大陆赛事",
    },
    "STREETS OF SAN": {
        "LL": [89],
        "L": [15],
        "RR": [68],
        "R": [60],
        "B": [],
        "BB": [42],
        "YY-1": [],
        "YY-2": [],
        "YY-3": [],
        "trackcn": "旧金山街道",
    },
    "CANYON LAUNCH": {
        "LL": [],
        "L": [2],
        "RR": [29],
        "R": [4],
        "B": [],
        "BB": [53],
        "YY-1": [90],
        "YY-2": [93],
        "YY-3": [19],
        "trackcn": "峡谷飞驰",
    },
    "NANJING STROLL": {
        "LL": [],
        "L": [15],
        "RR": [46],
        "R": [31],
        "B": [],
        "BB": [0],
        "YY-1": [3],
        "YY-2": [60],
        "YY-3": [71],
        "trackcn": "漫步南京路",
    },
    "THE ETERNAL CITY": {
        "LL": [71],
        "L": [8, 16, 64, 77, 82],
        "RR": [],
        "R": [21, 34, 44, 50, 57, 92],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "YY-3": [],
        "trackcn": "永恒之城",
    },
    "ANCIENT RUINS": {
        "LL": [],
        "L": [33, 40, 71, 87],
        "RR": [],
        "R": [1, 4, 15, 30, 51, 56, 67],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "YY-3": [],
        "trackcn": "古代遗迹",
    },
    "CLIFFHANGER": {
        "LL": [56],
        "L": [20, 24, 37, 44, 53, 60, 63],
        "RR": [],
        "R": [13, 76],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "YY-3": [],
        "trackcn": "悬崖峭壁",
    },
    "PANTHEON SPLIT": {
        "LL": [],
        "L": [1, 2, 14, 42, 58, 70, 81],
        "RR": [],
        "R": [10, 32],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "YY-3": [],
        "trackcn": "万神殿岔路",
    },
    "STARTING GRID": {
        "LL": [],
        "L": [4, 8, 13, 58, 67, 89],
        "RR": [],
        "R": [26, 75, 93],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "YY-3": [],
        "trackcn": "起跑排位",
    },
    "TUNNEL JAM": {
        "LL": [],
        "L": [8, 14, 15, 31, 59, 60, 69, 70, 74, 88],
        "RR": [],
        "R": [28, 35, 81, 82],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "YY-3": [],
        "trackcn": "拥堵隧道",
    },
    "PUDONG RISE": {
        "LL": [],
        "L": [3, 4, 14, 15, 17, 18, 23, 37, 38, 49, 50, 85, 86],
        "RR": [],
        "R": [46, 47, 63, 64, 89, 90, 93, 94, 96],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "YY-3": [],
        "trackcn": "浦东崛起",
    },
    "INDUSTRIAL RUN": {
        "LL": [],
        "L": [3, 4, 6, 7, 18, 19, 34, 35, 64, 65, 68, 69, 78, 79],
        "RR": [],
        "R": [14, 15, 55],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "YY-3": [],
        "trackcn": "工业区竞速",
    },
    "RUSH MINUTE": {
        "LL": [],
        "L": [9, 10, 48, 49, 70, 71, 75, 76],
        "RR": [],
        "R": [1, 2, 19, 20, 38, 39, 51, 52],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "YY-3": [],
        "trackcn": "尖峰时刻",
    },
    "SUBWAY SURFING": {
        "LL": [19, 20],
        "L": [],
        "RR": [16, 17],
        "R": [22, 23, 43, 58, 59, 84, 85],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "YY-3": [],
        "trackcn": "地铁冲浪",
    },
    "STRAIGHTS": {
        "LL": [],
        "L": [17, 18, 38, 39, 40, 41, 43, 44, 45, 46, 58, 59],
        "RR": [],
        "R": [9, 10, 51, 52, 68, 69, 75, 76, 77, 78, 80, 81, 95, 96],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "YY-3": [],
        "trackcn": "直道和弯道",
    },
    "CAPITAL OF THE WORLD": {
        "LL": [],
        "L": [1, 2, 13, 14, 38, 39, 44, 45, 67, 68, 91, 92],
        "RR": [],
        "R": [29, 30, 47, 48, 58, 59, 61, 62, 81, 82],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "YY-3": [],
        "trackcn": "世界大都会",
    },
    "DESERT RUN": {
        "LL": [],
        "L": [14, 15, 31, 32, 52, 53, 88, 89, 93, 94],
        "RR": [],
        "R": [0, 1, 4, 5, 9, 10, 25, 26, 69, 70, 79, 80],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "YY-3": [],
        "trackcn": "沙漠狂飙",
    },
    "THUNDERING": {
        "LL": [],
        "L": [16, 17, 31, 32],
        "RR": [],
        "R": [38, 39, 76, 77],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "YY-3": [],
        "trackcn": "雷鸣之始",
    },
    "FROZEN ROUTE": {
        "LL": [],
        "L": [22, 59, 70, 71, 73, 88],
        "RR": [75],
        "R": [2, 66],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "YY-3": [],
        "trackcn": "冰封路径",
    },
    "DESERT LIFE": {
        "LL": [],
        "L": [79],
        "RR": [],
        "R": [19, 22, 25, 30, 34, 42, 72, 83, 86, 93],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "YY-3": [],
        "trackcn": "沙漠生命",
    },
    "DAM BUSTER": {
        "LL": [],
        "L": [24, 29, 49, 82, 83, 91],
        "RR": [],
        "R": [6, 16, 35, 54, 69, 74, 80],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "YY-3": [],
        "trackcn": "大坝克星",
    },
    "LONG RUN": {
        "LL": [],
        "L": [26, 38],
        "RR": [],
        "R": [2, 59, 75, 79, 82, 90],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "YY-3": [],
        "trackcn": "长路慢慢",
    },
    "PIER PRESSURE": {
        "LL": [],
        "L": [40],
        "RR": [],
        "R": [25, 30, 65, 82],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "YY-3": [],
        "trackcn": "桥墩压力",
    },
}

==> ns_asphalt9-1.0.5-py3-none-any.whl: ns_asphalt9/core/utils/track_navi_data_update.py <==
data = {
    "LEGENDARY HUNT": {
        "LL": [],
        "L": [4, 5, 13, 14],
        "RR": [],
        "R": [],
        "B": [],
        "BB": [19, 20, 41, 42],
        "YY-1": [],
        "YY-2": [1],
        "trackcn": "通行证寻车",
    },
    # "LEGENDARY HUNT": {
    #     "LL": [],
    #     "L": [],
    #     "RR": [],
    #     "R": [],
    #     "B": [],
    #     "BB": [10, 20, 30, 40, 50, 60, 70, 80],
    #     "YY-1": [],
    #     "YY-2": [1],
    #     "trackcn": "通行证寻车",
    # },
    "DOWNTOWN RISE": {
        "LL": [],
        "L": [11, 50, 61, 76, 83, 86],
        "RR": [],
        "R": [16, 34, 64],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "市中心高架桥",
    },
    "THE CITY BY THE BAY": {
        "LL": [],
        "L": [31],
        "RR": [],
        "R": [8, 33, 69, 81, 85],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "临湾城市",
    },
    "UPTOWN": {
        "LL": [],
        "L": [41, 42, 66, 67],
        "RR": [],
        "R": [6, 7, 8, 25, 26, 44, 45, 69, 70, 80, 81, 84, 85, 86, 90, 91],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "住宅区",
    },
    "DIPPING DOWN": {
        "LL": [42],
        "L": [45, 52, 89],
        "RR": [],
        "R": [4, 19, 36, 65, 68, 73, 92],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "坠落",
    },
    "LEAPS & BOUNDS": {
        "LL": [59],
        "L": [63, 79, 90],
        "RR": [],
        "R": [],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "急速飞跃",
    },
    "TIBER STREAM": {
        "LL": [],
        "L": [1, 5, 6, 9, 11, 12, 31, 32, 42, 43, 67, 95, 96],
        "RR": [],
        "R": [3, 14, 15, 26, 27, 61, 65, 73, 74, 90],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "台伯河激流",
    },
    "THE CITY THAT NEVER SLEEPS": {
        "LL": [],
        "L": [5, 6, 7, 11, 12, 60, 61, 66, 67],
        "RR": [],
        "R": [2, 3, 31, 45, 46, 82, 83],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "不夜城",
    },
    "THE PEARL OF THE ORIENT": {
        "LL": [],
        "L": [5, 6, 13, 26, 30, 63, 64, 76, 77, 87],
        "RR": [],
        "R": [40, 41, 44, 45, 57, 59, 60],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "东方明珠",
    },
    "CAVE HEAT": {
        "LL": [],
        "L": [18, 19, 37, 53, 54],
        "RR": [],
        "R": [9, 10, 28, 29, 34, 35],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "洞穴热浪",
    },
    "MOUNTAIN POLES": {
        "LL": [],
        "L": [15, 16, 41, 42, 60, 82, 88],
        "RR": [],
        "R": [26, 31, 44, 45, 75, 76],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "山巅",
    },
    "DOWNHILL RUN": {
        "LL": [],
        "L": [19, 23, 62, 74, 78, 83],
        "RR": [],
        "R": [6, 14, 30, 50, 87],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "山地速降",
    },
    "THOUSAND": {
        "LL": [],
        "L": [10, 14, 20, 25, 56, 60, 84, 85, 86],
        "RR": [],
        "R": [0, 45, 79, 82],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "尖塔耸立",
    },
    "AUCKLAND TRACK": {
        "LL": [],
        "L": [0, 5, 8, 15, 23, 35, 71, 74],
        "RR": [],
        "R": [47, 61, 67],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "奥克兰赛道",
    },
    "ANCIENT ROME": {
        "LL": [],
        "L": [13, 19, 35, 50, 65],
        "RR": [],
        "R": [39, 40, 68, 79, 89],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "古罗马",
    },
    "BEACH LANDING": {
        "LL": [],
        "L": [1, 3, 11, 40, 54],
        "RR": [],
        "R": [8, 47, 59, 81, 89],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "海滩登陆",
    },
    "QUANTUM JUMPS": {
        "LL": [],
        "L": [15, 22, 52, 85],
        "RR": [],
        "R": [18, 26, 38, 62, 65, 79],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "量子跃迁",
    },
    "ROLLER": {
        "LL": [],
        "L": [3, 53, 66, 82],
        "RR": [23],
        "R": [19, 46, 56],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "云霄飞车",
    },
    "URBAN BLAZE": {
        "LL": [],
        "L": [51, 55, 68, 88],
        "RR": [],
        "R": [2, 9, 28, 33, 83],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "城市烈焰",
    },
    "WHIRLWIND": {
        "LL": [],
        "L": [4, 8, 79],
        "RR": [],
        "R": [18, 41, 68, 85, 92],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "旋风弯道",
    },
    "SHEN CITY": {
        "LL": [],
        "L": [5, 26, 50, 85],
        "RR": [],
        "R": [16, 22, 44, 67, 90],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "申城",
    },
    "THE PATH OF THE WIND": {
        "LL": [],
        "L": [22, 25, 49, 58],
        "RR": [],
        "R": [8, 18, 54, 69, 88, 91],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "风之小径",
    },
    "TRANSCONTINE RACE": {
        "LL": [],
        "L": [],
        "RR": [],
        "R": [2, 13, 26, 51, 65, 94],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "横贯大陆赛事",
    },
    "STREETS OF SAN": {
        "LL": [89],
        "L": [15, 60, 68],
        "RR": [],
        "R": [29, 42],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "旧金山街道",
    },
    "CANYON LAUNCH": {
        "LL": [],
        "L": [2, 4, 29, 43, 53, 90, 93],
        "RR": [],
        "R": [19, 63, 67, 78],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "峡谷飞驰",
    },
    "NANJING STROLL": {
        "LL": [],
        "L": [15, 31, 46, 80],
        "RR": [],
        "R": [0, 3, 60, 71, 87],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "漫步南京路",
    },
    "THE ETERNAL CITY": {
        "LL": [71],
        "L": [8, 16, 64, 77, 82],
        "RR": [],
        "R": [21, 34, 44, 50, 57, 92],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "永恒之城",
    },
    "ANCIENT RUINS": {
        "LL": [],
        "L": [33, 40, 71, 87],
        "RR": [],
        "R": [1, 4, 15, 30, 51, 56, 67],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "古代遗迹",
    },
    "CLIFFHANGER": {
        "LL": [56],
        "L": [20, 24, 37, 44, 53, 60, 63],
        "RR": [],
        "R": [13, 76],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "悬崖峭壁",
    },
    "PANTHEON SPLIT": {
        "LL": [],
        "L": [1, 2, 14, 42, 58, 70, 81],
        "RR": [],
        "R": [10, 32],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "万神殿岔路",
    },
    "STARTING GRID": {
        "LL": [],
        "L": [4, 8, 13, 58, 67, 89],
        "RR": [],
        "R": [26, 75, 93],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "起跑排位",
    },
    "TUNNEL JAM": {
        "LL": [],
        "L": [8, 14, 15, 31, 59, 60, 69, 70, 74, 88],
        "RR": [],
        "R": [28, 35, 81, 82],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "拥堵隧道",
    },
    "PUDONG RISE": {
        "LL": [],
        "L": [3, 4, 14, 15, 17, 18, 23, 37, 38, 49, 50, 85, 86],
        "RR": [],
        "R": [46, 47, 63, 64, 89, 90, 93, 94, 96],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "浦东崛起",
    },
    "INDUSTRIAL RUN": {
        "LL": [],
        "L": [3, 4, 6, 7, 18, 34, 35, 64, 65, 68, 69, 78, 79],
        "RR": [],
        "R": [14, 55],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "工业区竞速",
    },
    "RUSH MINUTE": {
        "LL": [],
        "L": [9, 48, 49, 70, 71, 75],
        "RR": [],
        "R": [1, 19, 20, 38, 39, 51],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "尖峰时刻",
    },
    "SUBWAY SURFING": {
        "LL": [19],
        "L": [],
        "RR": [16],
        "R": [2243, 58, 59, 84, 85],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "地铁冲浪",
    },
    "STRAIGHTS": {
        "LL": [],
        "L": [17, 38, 40, 41, 43, 44, 46, 58, 59],
        "RR": [],
        "R": [9, 51, 68, 75, 77, 80, 95],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "直道和弯道",
    },
    "CAPITAL OF THE WORLD": {
        "LL": [],
        "L": [1, 13, 38, 44, 67, 91],
        "RR": [],
        "R": [29, 30, 47, 58, 61, 81],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "世界大都会",
    },
    "DESERT RUN": {
        "LL": [],
        "L": [14, 31, 52, 88, 93],
        "RR": [],
        "R": [0, 1, 4, 9, 25, 69, 79],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "沙漠狂飙",
    },
    "THUNDERING": {
        "LL": [],
        "L": [16, 31],
        "RR": [],
        "R": [38, 76],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "雷鸣之始",
    },
    "UNDER CONSTRUC": {
        "LL": [],
        "L": [2, 41, 44],
        "RR": [],
        "R": [13, 20, 36, 69, 83, 92],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "建造施工",
    },
    "SAINT PETER": {
        "LL": [],
        "L": [1, 2, 36, 41, 84, 87],
        "RR": [],
        "R": [24, 27, 31, 48, 54],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "圣彼得狂飙",
    },
    "THE CURVE": {
        "LL": [],
        "L": [35, 43, 74],
        "RR": [],
        "R": [4, 20, 50, 53, 82],
        "B": ["2-3", "25-4", "32-2", "71-2"],
        "BB": [10, 14, 42, 57, 77],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "弯道争霸",
    },
    "FROZEN ROUTE": {
        "LL": [],
        "L": [22, 59, 70, 71, 73, 88],
        "RR": [75],
        "R": [2, 66],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "冰封路径",
    },
    "DESERT LIFE": {
        "LL": [],
        "L": [79],
        "RR": [],
        "R": [19, 22, 25, 30, 34, 42, 72, 83, 86, 93],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "沙漠生命",
    },
    "DAM BUSTER": {
        "LL": [],
        "L": [24, 29, 49, 82, 83, 91],
        "RR": [],
        "R": [6, 16, 35, 54, 69, 74, 80],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "大坝克星",
    },
    "LONG RUN": {
        "LL": [],
        "L": [26, 38],
        "RR": [],
        "R": [2, 59, 75, 79, 82, 90],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "长路慢慢",
    },
    "PIER PRESSURE": {
        "LL": [],
        "L": [40],
        "RR": [],
        "R": [25, 30, 65, 82],
        "B": [],
        "BB": [],
        "YY-1": [],
        "YY-2": [],
        "trackcn": "桥墩压力",
    },
}
